import { Switch, Route, useLocation, Link } from "wouter";
import { useEffect, useState, useCallback, createContext, lazy, Suspense, useMemo } from "react";
import { useAuth } from "./hooks/use-auth";
import { ProtectedRoute } from "./lib/protected-route";
import LaunchAnnouncement from "./components/ui/launch-announcement";
import CopyrightNotice from "./components/ui/copyright-notice";
import { useMobile } from "./providers/MobileProvider";
import { TooltipProvider } from "@/components/ui/tooltip";
import { HelmetProvider } from "react-helmet-async";
import "./i18n"; // Import i18n configuration
import { queryClient } from "./lib/queryClient";
import { LanguageProvider } from './contexts/LanguageContext';
import MotionBackgroundV2 from "@/components/ui/motion-background-v2";
import { CountdownProvider } from "@/components/ui/launch-countdown";
import { SoundInitializer } from "@/components/system/SoundInitializer";
// Performance optimization components
import StartupOptimizer from "@/components/system/StartupOptimizer";
import PreloadResources from "@/components/system/PreloadResources";
import InitializationGuard from "@/components/system/InitializationGuard";
// Import iOS-specific utilities and components
import FastLoading from "@/components/system/FastLoading";
import IOSRedirect from "@/components/iOS/IOSRedirect";
import IOSAuthRedirect from "@/components/ios/IOSAuthRedirect"; // Import iOS-specific auth redirect
import { isIOS, isIOS18, enhanceiOS18Session, applyIOSOptimizations } from "@/lib/ios-utils"; // Import iOS utils
// Import performance optimization utilities
import { clearAllCaches, initializePerformanceOptimizations } from "@/utils/performance-optimizer";

// Eager imports for critical components
import Login from "./pages/Login";
import NotFound from "@/pages/not-found";
import MobileLoginPage from "@/pages/mobile-login-page";
import IOSLoginPage from "@/pages/IOSLoginPage";
import AdaptiveDashboard from "@/components/dashboard/AdaptiveDashboard";
import NewDashboard from "@/pages/NewDashboard";

// Mobile device detection import
import { isMobileDevice } from "@/lib/deviceDetector";

// Create context for UI overlay state
export type UIOverlayContextType = {
  isMenuOpen: boolean;
  setIsMenuOpen: (isOpen: boolean) => void;
  floatingButtonsVisible: boolean;
  setFloatingButtonsVisible: (visible: boolean) => void;
};

export const UIOverlayContext = createContext<UIOverlayContextType>({
  isMenuOpen: false,
  setIsMenuOpen: () => {},
  floatingButtonsVisible: true,
  setFloatingButtonsVisible: () => {},
});

// Lazy imports for all other components
const Auth = lazy(() => import("./pages/Auth"));
const SimpleAuth = lazy(() => import("./pages/SimpleAuth"));
// Import the new unified auth page
const UnifiedAuthPage = lazy(() => import("./pages/UnifiedAuthPage"));
const Referrals = lazy(() => import("./pages/Referrals"));
const ReferralMatrixPage = lazy(() => import("./pages/ReferralMatrixPage"));
const Games = lazy(() => import("./pages/Games"));
const Transactions = lazy(() => import("./pages/Transactions"));
const Subscription = lazy(() => import("./pages/Subscription"));
const SubscriptionComplete = lazy(() => import("./pages/SubscriptionComplete"));
const SubscriptionManagement = lazy(() => import("./pages/SubscriptionManagement"));
const SubscriptionCancel = lazy(() => import("./pages/SubscriptionCancel"));
const SubscriptionPaymentUpdate = lazy(() => import("./pages/SubscriptionPaymentUpdate"));
const FeaturesManagement = lazy(() => import("./pages/FeaturesManagement"));
const PaymentManagement = lazy(() => import("./pages/PaymentManagement"));
const FinancialTools = lazy(() => import("./pages/FinancialTools"));
const Profile = lazy(() => import("./pages/Profile"));
const Help = lazy(() => import("./pages/Help"));
const Surveys = lazy(() => import("./pages/Surveys"));
const Payment = lazy(() => import("./pages/Payment"));
const Guides = lazy(() => import("./pages/Guides"));
const Chat = lazy(() => import("./pages/Chat"));
const Admin = lazy(() => import("./pages/Admin"));
const Terms = lazy(() => import("./pages/Terms"));
const Privacy = lazy(() => import("./pages/Privacy"));
const Cookies = lazy(() => import("./pages/Cookies"));
const DailyChallenges = lazy(() => import("./pages/DailyChallenges"));
const Checkout = lazy(() => import("./pages/Checkout"));
const CheckoutSuccess = lazy(() => import("./pages/CheckoutSuccess"));
const PaymentSuccess = lazy(() => import("./pages/payment-success"));
const Multiplayer = lazy(() => import("./pages/Multiplayer"));
const NotificationTest = lazy(() => import("./pages/NotificationTest"));
const SecurityReport = lazy(() => import("./pages/SecurityReport"));
const UXEnhancements = lazy(() => import("./pages/UXEnhancements"));
const CryptoWallet = lazy(() => import("./pages/CryptoWallet"));
const AccessibilityHelp = lazy(() => import("./pages/AccessibilityHelp"));
const Accessibility = lazy(() => import("./pages/Accessibility"));
const AboutUs = lazy(() => import("./pages/AboutUs"));
const OurMission = lazy(() => import("./pages/OurMission"));
const Careers = lazy(() => import("./pages/Careers"));
const CareersApply = lazy(() => import("./pages/CareersApply"));
const Press = lazy(() => import("./pages/Press"));
const Blog = lazy(() => import("./pages/Blog"));
const Contact = lazy(() => import("./pages/Contact"));
const ApiDocs = lazy(() => import("./pages/ApiDocs"));
const Community = lazy(() => import("./pages/Community"));
const Partners = lazy(() => import("./pages/Partners"));
const Partnerships = lazy(() => import("./pages/Partnerships"));
const PartnerApplication = lazy(() => import("./pages/PartnerApplication"));
const LanguageSettings = lazy(() => import("./pages/LanguageSettings"));
const SupportTickets = lazy(() => import("./pages/SupportTickets"));
const CacheSettings = lazy(() => import("./pages/CacheSettings"));
const Security = lazy(() => import("./pages/Security"));
const SoundTestPage = lazy(() => import("./pages/SoundTestPage"));
const SoundTest = lazy(() => import("./pages/SoundTest"));
const LicenseVerification = lazy(() => import("./pages/LicenseVerification"));
const IPRights = lazy(() => import("./pages/IPRights"));
const TeamLicense = lazy(() => import("./pages/TeamLicense"));
const TeamSubscriptionPage = lazy(() => import("./pages/TeamSubscriptionPage"));
const Waitlist = lazy(() => import("./pages/Waitlist"));
const NetworkStatus = lazy(() => import("./pages/network-status"));

// UI components
const Header = lazy(() => import("@/components/layout/Header"));
const Sidebar = lazy(() => import("@/components/layout/Sidebar"));
const MobileNavigation = lazy(() => import("@/components/layout/MobileNavigation"));
const Footer = lazy(() => import("@/components/layout/Footer"));
const MainLayout = lazy(() => import("@/components/layout/MainLayout.jsx"));
const EnhancedMotionBackground = lazy(() => import("@/components/ui/enhanced-motion-background"));

// Import components with named exports
const SupportButtonModule = lazy(() => 
  import("@/components/ui/support-button")
    .then(module => ({ default: module.SupportButton }))
);

const QuickActionMenuModule = lazy(() => 
  import("@/components/ui/quick-action-menu")
    .then(module => ({ default: module.QuickActionMenu }))
);

const FloatingButtonsControllerModule = lazy(() => 
  import("@/components/ui/floating-buttons-controller")
    .then(module => ({ default: module.FloatingButtonsController }))
);

// PennyChatModal is now imported directly in MainLayout.jsx
// We removed the lazy-loaded version to prevent duplicate instances and conflicts

const AppErrorBoundary = lazy(() => import('./components/ErrorBoundary'));

// Initialize toast system for global error handling
const ToastInitializer = () => {
  // This component simply ensures toasts can be shown from anywhere
  return null;
};

// Import optimized loading components
import { FullPageLoader } from '@/components/ui/loader';
import LoadingScreen from '@/components/LoadingScreen';
import * as performanceUtils from '@/utils/performance-optimizer';

// Use optimized LoadingScreen for consistent user experience
const LoadingIndicator = () => <LoadingScreen message="Loading application..." showAfterMs={100} />;

interface AppProps {
  isMobile?: boolean;
}

function App({ isMobile: propIsMobile }: AppProps = {}) {
  const [location] = useLocation();
  // UI Context state variables
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [floatingButtonsVisible, setFloatingButtonsVisible] = useState(true);
  const [showEmergencyFallback, setShowEmergencyFallback] = useState(false);
  
  // Log UI context state initialization
  useEffect(() => {
    console.log("App: UIOverlayContext initialized", { isMenuOpen, floatingButtonsVisible });
  }, [isMenuOpen, floatingButtonsVisible]);
  
  // Show emergency fallback if application takes too long to load
  useEffect(() => {
    const timeoutId = setTimeout(() => {
      console.log("🚨 EMERGENCY: App failed to initialize properly, showing fallback UI");
      setShowEmergencyFallback(true);
    }, 3000); // Show fallback after 3 seconds if app doesn't load
    
    return () => clearTimeout(timeoutId);
  }, []);
  
  const [performanceOptimized, setPerformanceOptimized] = useState(false);
  
  // Get mobile context to handle device-specific behaviors
  const { isMobile, isIOS, isAndroid, isMobileReady } = useMobile();
  
  // Dispatch app-mounted event when the app is loaded
  useEffect(() => {
    const dispatchAppMounted = () => {
      try {
        console.log('App.tsx: Dispatching app-mounted event');
        const appMountedEvent = new Event('app-mounted', { bubbles: true });
        document.dispatchEvent(appMountedEvent);
        
        // Also try to cleanup any emergency UI directly
        if (typeof (window as any).cleanupEmergencyUI === 'function') {
          (window as any).cleanupEmergencyUI();
        }
      } catch (error) {
        console.error('App.tsx: Error dispatching app-mounted event:', error);
      }
    };
    
    // Dispatch the event after a short delay to ensure the app is fully rendered
    const timeoutId = setTimeout(dispatchAppMounted, 500);
    return () => clearTimeout(timeoutId);
  }, []);

  // ROBUST loading screen handling
  useEffect(() => {
    function hideScreenAggressively() {
      try {
        // Directly target element - do not rely on window methods
        const loadingContainer = document.getElementById('loading-container');
        if (loadingContainer) {
          console.log('App.tsx: Forcefully hiding loading screen');
          
          // Multi-layered approach to ensure it's hidden
          loadingContainer.style.visibility = 'hidden';
          loadingContainer.style.opacity = '0';
          loadingContainer.style.display = 'none';
          loadingContainer.style.pointerEvents = 'none';
          loadingContainer.style.zIndex = '-9999';
          
          // Force browser to repaint by accessing offsetHeight
          loadingContainer.offsetHeight;
          
          // Mark as hidden
          window.__LOADING_SCREEN_HIDDEN = true;
          console.log('App.tsx: Loading screen forcefully hidden');
        }
      } catch (e) {
        console.error('Failed to forcefully hide loading screen:', e);
      }
    }
  
    // Apply MULTIPLE independent attempts to hide the loading screen
    if (typeof window !== 'undefined') {
      // First attempt - immediate
      hideScreenAggressively();
      
      // Second attempt - after short delay
      setTimeout(hideScreenAggressively, 300);
      
      // Third attempt - use the window function if available
      setTimeout(() => {
        if (typeof window.hideLoadingScreen === 'function') {
          try {
            window.hideLoadingScreen();
          } catch (e) {
            console.error('Error using window.hideLoadingScreen:', e);
          }
        }
        
        // Cleanup timeout
        if (typeof window.clearStartupTimeout === 'function') {
          window.clearStartupTimeout();
          console.log('App is fully loaded, clearing startup timeout');
        }
      }, 600);
      
      // Fourth attempt - extra insurance
      setTimeout(hideScreenAggressively, 1000);
    }
  }, []);
  
  const [startupTime] = useState(() => {
    // Record startup metrics if available
    const metrics = window.__PEERPA_LOAD_METRICS;
    if (metrics) {
      console.log("App startup metrics:", {
        appImport: metrics.appImport ? Math.round(metrics.appImport) + "ms" : "N/A",
        appRender: metrics.appRender ? Math.round(metrics.appRender) + "ms" : "N/A", 
        totalStartupTime: metrics.fullAppLoaded ? Math.round(metrics.fullAppLoaded) + "ms" : "N/A"
      });
    }
    return Date.now();
  });
  
  console.log("Main component rendering at:", new Date().toISOString());
  console.log("Current location:", location);

  // Clear the startup timeout when component mounts - this indicates successful app initialization
  useEffect(() => {
    // Clear startup timeout to prevent error display
    if (window.clearStartupTimeout) {
      window.clearStartupTimeout();
      console.log('App successfully initialized - startup timeout cleared');
    }
  }, []);

  // Fetch current user data for auth status - optimized to prevent excessive calls
  useEffect(() => {
    // Store last auth check timestamp to prevent excessive calls
    const lastAuthCheck = sessionStorage.getItem('lastAuthCheck');
    const now = Date.now();
    
    // Prevent multiple auth checks within a short time period (3 seconds)
    // but always run on first load
    if (lastAuthCheck && now - parseInt(lastAuthCheck, 10) < 3000) {
      console.log("App: Skipping redundant auth check");
      return;
    }
    
    // Record this auth check
    sessionStorage.setItem('lastAuthCheck', now.toString());
    
    // Use immediate loading instead of staggered loading for faster startup
    console.log("App: Fetching current user from API...");

    // Check if we already have user data in localStorage
    const storedUser = localStorage.getItem('authUser');
    const sessionAuth = sessionStorage.getItem('sessionAuthenticated');
    
    // If we have stored user data and valid session, use it immediately
    if (storedUser && sessionAuth === 'true') {
      try {
        const userData = JSON.parse(storedUser);
        // Only use cached user data if it's properly formed
        if (userData && userData.id) {
          console.log("App: Using cached user data:", userData.username);
          // Note: we no longer directly set user data here, the useAuth hook handles this
        }
      } catch (e) {
        console.error("App: Error parsing stored user data:", e);
        // Clear invalid data
        localStorage.removeItem('authUser');
      }
    }
    
    // Immediately verify with server instead of delaying
    const timer = setTimeout(() => {
      // Use the API function from our lib/api.ts to get current user
      import('./lib/api').then(({ getCurrentUser }) => {
        getCurrentUser()
          .then(userData => {
            if (userData) {
              console.log("App: Current user data from API:", userData.username);
              localStorage.setItem('authUser', JSON.stringify(userData));
              sessionStorage.setItem('sessionAuthenticated', 'true');
              
              // Store the user data for auth - the useAuth hook now handles state management
              console.log("User data stored for auth context");
            }
          })
          .catch(error => {
            console.error("App: Error fetching current user:", error);
          });
      })
      .catch(error => {
        console.error("App: Error importing API functions:", error);
      });
    }, 0); // Run immediately, without any delay
    
    return () => clearTimeout(timer);
  }, []);
  
  // Hide floating buttons when on chat page or when triggered by a component
  useEffect(() => {
    // Always check URL first
    if (location === '/chat') {
      setFloatingButtonsVisible(false);
    } else if (location === '/help') {
      // Don't set to true for Help page - the Help component will manage visibility
      // based on whether the chat is open or not
      console.log("On help page - component will manage floating buttons visibility");
    } else {
      // For all other pages, show the floating buttons by default
      setFloatingButtonsVisible(true);
    }
  }, [location]);
  
  // Listen for global events to control floating buttons visibility
  useEffect(() => {
    const handleShowChat = () => {
      console.log("Global event: hidingFloatingButtons received");
      setFloatingButtonsVisible(false);
    };
    
    const handleHideChat = () => {
      console.log("Global event: showingFloatingButtons received");
      setFloatingButtonsVisible(true);
    };
    
    // Register global event listeners
    document.addEventListener('hidingFloatingButtons', handleShowChat);
    document.addEventListener('showingFloatingButtons', handleHideChat);
    
    return () => {
      // Clean up event listeners
      document.removeEventListener('hidingFloatingButtons', handleShowChat);
      document.removeEventListener('showingFloatingButtons', handleHideChat);
    };
  }, []);
  
  // Initialize enhanced iOS detection and apply optimizations
  useEffect(() => {
    try {
      // Check if this is an iOS device using our new utility
      const deviceIsIOS = typeof isIOS === 'function' ? isIOS() : false;
      const deviceIsIOS18 = typeof isIOS18 === 'function' ? isIOS18() : false;
      
      if (deviceIsIOS) {
        console.log("iOS device detected, applying optimizations");
        // Apply general iOS optimizations
        applyIOSOptimizations();
        
        // Set global flag for iOS detection
        window.__IS_IOS_DEVICE = true;
        
        // For iOS 18, apply additional optimizations
        if (deviceIsIOS18) {
          console.log("iOS 18 detected, applying specialized enhancements");
          enhanceiOS18Session();
          
          // Set global flag for iOS 18 detection
          window.__IS_IOS18_DEVICE = true;
        }
      }
    } catch (error) {
      console.error("Error in iOS detection:", error);
    }
  }, []);
  
  // Initialize comprehensive performance optimizations with shorter timeout
  useEffect(() => {
    // Create a timeout to prevent hanging app initialization
    const initTimeout = setTimeout(() => {
      console.log("Performance optimization initialization timed out, continuing app startup");
      // Force app to continue even if optimizations are still running
      window.__APP_INITIALIZATION_COMPLETE = true;
    }, 5000); // 5 second timeout
    
    try {
      console.log("App: Initializing comprehensive performance optimizations...");
      
      // Apply a comprehensive suite of optimizations using all our utility modules
      Promise.all([
        // Performance optimizer - cache clearing and resource optimization
        import('./utils/performance-optimizer').then(module => {
          // Check if the module has the clearAppCache function
          if (module.clearAppCache) {
            module.clearAppCache()
              .then(result => console.log("App: Caches cleared:", result ? "success" : "failed"))
              .catch(err => console.warn("App: Cache clearing error:", err));
          }
          
          module.initializePerformanceOptimizations();
          console.log("App: Performance optimizations initialized");
          return { cleanup: () => console.log("Cleanup called") };
        }),
        
        // Startup optimizer - critical function prewarming and asset preloading
        import('./utils/startup-optimizer').then(module => {
          module.optimizeStartupSequence();
          console.log("App: Startup sequence optimized");
          return module;
        }),
        
        // Appearance optimizer - ensuring all content is properly visible
        import('./utils/appearance-optimizer').then(module => {
          module.fixAppearanceIssues();
          console.log("App: Appearance issues fixed");
          return module;
        }),
        
        // iOS-specific optimizations if needed
        import('./utils/ios-optimization').then(module => {
          if (module.isIOSDevice()) {
            console.log("App: iOS device detected, applying specialized fixes");
            module.applyIOS18Fixes();
          }
          return module;
        })
      ]).then(([performanceModule]) => {
        console.log("App: All optimization modules successfully loaded and applied");
      }).catch(error => {
        // If dynamic imports fail, fall back to direct method calls
        console.error("App: Dynamic optimization import failed using direct methods:", error);
        // Cannot call direct methods here as they're not available in this scope
        // Just log the error and continue
      });
      
      // Force redraw of all content to ensure proper visibility (fallback approach)
      setTimeout(() => {
        const mainContent = document.querySelector('main');
        if (mainContent) {
          console.log("App: Forcing content redraw for visibility");
          mainContent.style.opacity = '0.99';
          setTimeout(() => {
            mainContent.style.opacity = '1';
          }, 30);
        }
      }, 500);
      
      // Return a cleanup function that will be called when component unmounts
      return () => {
        console.log("App: Cleaning up performance optimizations");
        // We don't have a reference to cleanupFn from Promise.all,
        // but we can import and call relevant cleanup functions if needed
        try {
          // Just import the module without trying to call a specific cleanup function
          // The module itself handles its own cleanup safely
          import('./utils/performance-optimizer').then(module => {
            console.log("App: Cleaning up performance optimizations");
          });
        } catch (e) {
          console.error("App: Error during optimization cleanup:", e);
        }
      };
    } catch (error) {
      console.error("Error initializing performance optimizations:", error);
    }
  }, []);
  
  // Add mobile-specific behavior once mobile context is ready
  useEffect(() => {
    if (isMobileReady) {
      console.log("Mobile context is ready, device is", isMobile ? "mobile" : "desktop");
      
      if (isMobile) {
        // Apply mobile-specific behaviors
        console.log("Applying mobile-specific behaviors in App component");
        
        // Add classes to help with styling
        document.documentElement.classList.add('app-mobile-ready');
        
        // For Android devices, verify fixes were applied and set flag
        if (isAndroid) {
          try {
            // EMERGENCY FIX: Always apply Android fixes when loaded
            // without triggering a reload loop
            if (!document.documentElement.classList.contains('android-fixes-applied')) {
              console.log('Adding Android optimizations directly');
              document.documentElement.classList.add('android-fixes-applied');
              
              // Apply hardware acceleration
              document.documentElement.style.setProperty('will-change', 'transform');
              document.documentElement.style.setProperty('backface-visibility', 'hidden');
              
              // Store that we've applied fixes
              localStorage.setItem('peerpa.androidFixesApplied', Date.now().toString());
            }
            
            // Add Android-specific class if not already present
            if (!document.documentElement.classList.contains('android-device')) {
              document.documentElement.classList.add('android-device');
            }
          } catch (e) {
            console.error('Error checking Android fixes:', e);
          }
        }
        
        // Log device info for debugging
        console.log("Mobile device info:", { 
          isIOS, 
          isAndroid,
          userAgent: navigator.userAgent,
          viewportWidth: window.innerWidth,
          viewportHeight: window.innerHeight,
          androidFixesApplied: localStorage.getItem('peerpa.androidFixesApplied') ? 'yes' : 'no'
        });
      }
    }
  }, [isMobile, isIOS, isAndroid, isMobileReady]);
  
  // Get user data from context
  const { user } = useAuth();
  
  // Clear the startup timeout when app is successfully loaded
  useEffect(() => {
    if (isMobileReady) {
      // App is ready and mobile context is available
      // We'll clear the timeout even without user to avoid hanging
      if (window.clearStartupTimeout) {
        console.log("App is fully loaded, clearing startup timeout");
        window.clearStartupTimeout();
      } else {
        console.log("Warning: clearStartupTimeout function not available");
      }
      
      // Show success message for troubleshooting
      if (isAndroid) {
        console.log(`Android device successfully loaded the application! ${Date.now()}`);
      }
      
      // Update loading screen
      const loadingElement = document.getElementById('application-loading');
      if (loadingElement) {
        console.log("Hiding loading screen");
        loadingElement.classList.add('completed');
        // Remove loading element after fade out completes
        setTimeout(() => {
          loadingElement.style.display = 'none';
        }, 500);
      }
    }
  }, [isMobileReady, isAndroid]);

  // Define all routes in an array for easier management
  const routes = [
    // Protected routes - using adaptive dashboard for better cross-platform rendering
    { path: "/", component: AdaptiveDashboard },
    { path: "/dashboard", component: AdaptiveDashboard },
    { path: "/new-dashboard", component: NewDashboard },
    { path: "/referrals", component: Referrals },
    { path: "/matrix", component: ReferralMatrixPage },
    { path: "/games", component: Games },
    { path: "/games/:gameId", component: Games },
    { path: "/multiplayer", component: Multiplayer },
    { path: "/daily-challenges", component: DailyChallenges },
    { path: "/transactions", component: Transactions },
    { path: "/profile", component: Profile },
    { path: "/help", component: Help },
    { path: "/help/accessibility", component: AccessibilityHelp },
    { path: "/subscription", component: Subscription },
    { path: "/subscription/complete", component: SubscriptionComplete },
    { path: "/subscription/manage", component: SubscriptionManagement },
    { path: "/subscription-management", component: SubscriptionManagement },
    { path: "/subscribe", component: Subscription },
    { path: "/checkout", component: Checkout },
    { path: "/checkout-success", component: CheckoutSuccess },
    { path: "/subscription/manage/features", component: FeaturesManagement },
    { path: "/subscription/manage/payment", component: PaymentManagement },
    { path: "/subscription/manage/payment/update", component: SubscriptionPaymentUpdate },
    { path: "/subscription/manage/cancel", component: SubscriptionCancel },
    { path: "/financial-tools", component: FinancialTools },
    { path: "/payments", component: PaymentManagement },
    { path: "/payment", component: Payment },
    { path: "/payment-success", component: PaymentSuccess },
    { path: "/guides", component: Guides },
    { path: "/surveys", component: Surveys },
    { path: "/network-status", component: NetworkStatus },
    { path: "/admin", component: Admin },
    { path: "/language-settings", component: LanguageSettings },
    { path: "/profile/language", component: LanguageSettings },
    { path: "/support-tickets", component: SupportTickets },
    { path: "/notifications/test", component: NotificationTest },
    { path: "/help/security-report", component: SecurityReport },
    { path: "/settings/cache", component: CacheSettings },
    { path: "/security-center", component: Security },
    { path: "/crypto-wallet", component: CryptoWallet },
    { path: "/sound-test", component: SoundTestPage, public: true },
    { path: "/sound-test-new", component: SoundTest, public: true },
    { path: "/license", component: LicenseVerification, public: true },
    { path: "/ip-rights", component: IPRights, public: true },
    { path: "/team", component: TeamLicense, public: true },
    { path: "/team-subscription", component: TeamSubscriptionPage },
    { path: "/waitlist", component: Waitlist },
    
    // Public pages (no auth required)
    { path: "/unified-auth", component: UnifiedAuthPage, public: true }, // New consolidated auth page
    
    // Legacy auth routes - all point to the new UnifiedAuthPage for compatibility
    { path: "/login", component: UnifiedAuthPage, public: true },
    { path: "/register", component: UnifiedAuthPage, public: true },
    { path: "/auth", component: UnifiedAuthPage, public: true },
    { path: "/mobile-login", component: UnifiedAuthPage, public: true },
    // iOS-specific optimized login page
    { path: "/ios-login", component: IOSLoginPage, public: true },
    { path: "/chat", component: Chat, public: true },
    { path: "/terms", component: Terms, public: true },
    { path: "/privacy", component: Privacy, public: true },
    { path: "/cookies", component: Cookies, public: true },
    { path: "/security", component: Security, public: true },
    { path: "/accessibility", component: Accessibility, public: true },
    { path: "/about", component: AboutUs, public: true },
    { path: "/our-mission", component: OurMission, public: true },
    { path: "/careers", component: Careers, public: true },
    { path: "/careers/apply", component: CareersApply, public: true },
    { path: "/press", component: Press, public: true },
    { path: "/blog", component: Blog, public: true },
    { path: "/contact", component: Contact, public: true },
    { path: "/api-docs", component: ApiDocs, public: true },
    { path: "/community", component: Community, public: true },
    { path: "/community/discussions", component: Community, public: true },
    { path: "/community/forum/:id", component: Community, public: true },
    { path: "/community/topic/:id", component: Community, public: true },
    { path: "/community/all-forums", component: Community, public: true },
    { path: "/community/success-stories", component: Community, public: true },
    { path: "/community/success-story/:id", component: Community, public: true },
    { path: "/community/all-events", component: Community, public: true },
    { path: "/community/member/:id", component: Community, public: true },
    { path: "/community/members", component: Community, public: true },
    { path: "/community/resource/:id", component: Community, public: true },
    { path: "/community/resources", component: Community, public: true },
    { path: "/community/event/:id", component: Community, public: true },
    { path: "/partners", component: Partners, public: true },
    { path: "/partnerships", component: Partnerships, public: true },
    { path: "/partner", component: PartnerApplication, public: true },
    { path: "/partner-application", component: PartnerApplication, public: true },
    { path: "/ux-enhancements", component: UXEnhancements, public: true },
  ];

  // Function to handle ErrorBoundary resets
  const handleErrorReset = () => {
    console.log("Error boundary reset triggered");
    // Manual error recovery (simplified)
    try {
      // Clear any error caches that might be in localStorage
      const errorKeys = Object.keys(localStorage).filter(k => k.startsWith('error_'));
      errorKeys.forEach(key => localStorage.removeItem(key));
      
      // Refresh critical app state
      console.log("Performing app state recovery");
      
      // Force re-authentication if needed
      const authUser = localStorage.getItem('authUser');
      if (authUser) {
        try {
          // Try to parse and validate stored user data
          const userData = JSON.parse(authUser);
          if (!userData || !userData.id) {
            console.log("Invalid stored user data, removing");
            localStorage.removeItem('authUser');
            sessionStorage.removeItem('sessionAuthenticated');
          }
        } catch (e) {
          console.log("Corrupted auth data, removing", e);
          localStorage.removeItem('authUser');
          sessionStorage.removeItem('sessionAuthenticated');
        }
      }
    } catch (error) {
      console.error("Recovery failed:", error);
    }
  };

  // Handle iOS detection but without using simplified layout
  useEffect(() => {
    // Check if this is an iOS device
    const isIOS = navigator.userAgent.includes('iPhone') || 
                  navigator.userAgent.includes('iPad') || 
                  navigator.userAgent.includes('iPod');
    
    // Check specifically for iOS 18.3.1
    const isIOS1831 = isIOS && 
                      navigator.userAgent.includes('OS 18_3_1') && 
                      navigator.userAgent.includes('AppleWebKit');
    
    if (isIOS) {
      // Set a cookie so the server knows this is an iOS device
      document.cookie = "iOS18_detected=true; path=/; max-age=86400";
      
      if (isIOS1831) {
        // Add specific cookie for iOS 18.3.1
        document.cookie = "iOS18_3_1_detected=true; path=/; max-age=86400";
        console.log("iOS 18.3.1 detected - applying connection optimizations");
        
        // Disable sound loading to prevent unnecessary errors on problematic devices
        try {
          if (window.peerpaSettings && window.peerpaSettings.audio) {
            window.peerpaSettings.audio.enabled = false;
            window.peerpaSettings.audio.soundEnabled = false;
            window.peerpaSettings.audio.musicEnabled = false;
            console.log("Sound disabled for iOS 18.3.1 compatibility");
          }
        } catch (e) {
          console.error("Could not disable sound for iOS 18.3.1:", e);
        }
      }
    }
  }, []);
  
  // For all other devices, use the normal application
  return (
    <HelmetProvider>
      <InitializationGuard />
      <IOSRedirect showNotifications={false}>
        <TooltipProvider>
          <UIOverlayContext.Provider value={{ 
            isMenuOpen, 
            setIsMenuOpen, 
            floatingButtonsVisible, 
            setFloatingButtonsVisible 
          }}>
            <CountdownProvider>
            {/* Performance optimizers for faster startup */}
            <StartupOptimizer />
            <PreloadResources />
            
            {/* Initialize toast system for global error handling */}
            <ToastInitializer />
            
            {/* Initialize sound system */}
            <SoundInitializer />
            
            {/* Wrap the entire application in an ErrorBoundary for self-healing */}
            <Suspense fallback={<LoadingScreen message="Loading application..." />}>
            <AppErrorBoundary onReset={handleErrorReset}>
              {/* Enhanced motion background with more visible animation */}
              <div id="background-container" className="fixed inset-0 z-[-1] overflow-hidden pointer-events-none">
                <div id="animated-bg" className="absolute inset-0 opacity-15 bg-gradient-to-br from-primary/30 to-accent/30 animate-gradient"></div>
                <div id="bg-radial" className="absolute inset-0 bg-gradient-radial from-primary/10 to-transparent"></div>
              </div>
              
              {/* Lazy load the EnhancedMotionBackground for better performance */}
              <Suspense fallback={null}>
                {!isMobile && <EnhancedMotionBackground intensity="medium" primaryColor="#3b82f6" secondaryColor="#9333ea" particleCount={80} speed={1.2} />}
              </Suspense>
              
              {/* Routes with consistent loading screens */}
              <div className="App relative">
                <Switch>
                  {routes.map(({ path, component: Component, public: isPublic }) => {
                    if (isPublic) {
                      return (
                        <Route
                          key={path}
                          path={path}
                          component={() => (
                            <Suspense fallback={<LoadingScreen message="Loading page..." showAfterMs={100} />}>
                              <Component />
                            </Suspense>
                          )}
                        />
                      );
                    } else {
                      return (
                        <ProtectedRoute
                          key={path} 
                          path={path}
                          component={() => (
                            <Suspense fallback={<LoadingScreen message="Loading content..." showAfterMs={100} />}>
                              <Component />
                            </Suspense>
                          )}
                        />
                      );
                    }
                  })}
                  <Route component={NotFound} />
                </Switch>
              </div>
            </AppErrorBoundary>
          </Suspense>
          </CountdownProvider>
        </UIOverlayContext.Provider>
      </TooltipProvider>
    </IOSRedirect>
  </HelmetProvider>);
}

// Create a wrapper component that includes the FastLoading component as a fallback
function AppWithEmergencyFallback() {
  // State to track whether emergency fallback should be shown
  const [showEmergencyFallback, setShowEmergencyFallback] = useState(false);
  // State to track whether the app has fully loaded
  const [appFullyLoaded, setAppFullyLoaded] = useState(false);
  
  // Set a timeout to show the emergency fallback if the app doesn't load in time
  useEffect(() => {
    console.log("Emergency fallback component initialized");
    
    // Timer to trigger the emergency UI if needed
    const emergencyTimeoutId = setTimeout(() => {
      console.log("🚨 EMERGENCY: App initialization timeout - showing emergency UI");
      setShowEmergencyFallback(true);
    }, 1500); // Reduce timeout to 1.5 seconds for faster emergency UI display
    
    // Mark the app as loaded when it's fully rendered
    const loadedTimeoutId = setTimeout(() => {
      setAppFullyLoaded(true);
      console.log("App marked as fully loaded");
    }, 10000); // Set a maximum time after which we consider the app fully loaded
    
    return () => {
      clearTimeout(emergencyTimeoutId);
      clearTimeout(loadedTimeoutId);
    };
  }, []);
  
  // If the app is fully loaded, remove the emergency UI even if it was shown
  useEffect(() => {
    if (appFullyLoaded && showEmergencyFallback) {
      console.log("App fully loaded, hiding emergency UI");
      setShowEmergencyFallback(false);
    }
  }, [appFullyLoaded, showEmergencyFallback]);
  
  // If emergency fallback should be shown, render both FastLoading and App
  // FastLoading will be visible while App loads in the background
  if (showEmergencyFallback) {
    return (
      <>
        <FastLoading />
        <div style={{ visibility: 'hidden', position: 'absolute', top: 0, left: 0, width: '100%', height: '100%' }}>
          <App />
        </div>
      </>
    );
  }
  
  // Otherwise, render the normal app
  return <App />;
}

export default AppWithEmergencyFallback;